import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountEmails } from '../models/accountEmails';
import { DeletedResponse } from '../models/deletedResponse';
import { Configuration } from '../configuration';
import { AccountEmailsServiceInterface } from './accountEmails.serviceInterface';
export declare class AccountEmailsService implements AccountEmailsServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one AccountEmail.
     * Add one AccountEmail.
     * @param handedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addAccountEmails(handedOvers: AccountEmails, observe?: 'body', reportProgress?: boolean): Observable<AccountEmails>;
    addAccountEmails(handedOvers: AccountEmails, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<AccountEmails>>;
    addAccountEmails(handedOvers: AccountEmails, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<AccountEmails>>;
    /**
     * Delete one AccountEmail.
     * Delete one AccountEmail.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteAccountEmail(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteAccountEmail(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteAccountEmail(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one AccountEmail.
     * Edit one AccountEmail.
     * @param handedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editAccountEmail(handedOvers: AccountEmails, observe?: 'body', reportProgress?: boolean): Observable<AccountEmails>;
    editAccountEmail(handedOvers: AccountEmails, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<AccountEmails>>;
    editAccountEmail(handedOvers: AccountEmails, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<AccountEmails>>;
    /**
     * Get one AccountEmail.
     * Get one AccountEmail.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAccountEmailById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<AccountEmails>;
    getAccountEmailById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<AccountEmails>>;
    getAccountEmailById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<AccountEmails>>;
    /**
     * Get all AccountEmails.
     * Get all AccountEmails.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAccountEmails(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<AccountEmails>>;
    getAccountEmails(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<AccountEmails>>>;
    getAccountEmails(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<AccountEmails>>>;
}
