import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Accounts } from '../models/accounts';
import { DeletedResponse } from '../models/deletedResponse';
import { Configuration } from '../configuration';
import { AccountsServiceInterface } from './accounts.serviceInterface';
export declare class AccountsService implements AccountsServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one Account.
     * Add one Account.
     * @param accounts
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addAccount(accounts: Accounts, observe?: 'body', reportProgress?: boolean): Observable<Accounts>;
    addAccount(accounts: Accounts, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Accounts>>;
    addAccount(accounts: Accounts, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Accounts>>;
    /**
     * Delete one Account.
     * Delete one Account.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteAccount(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteAccount(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteAccount(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one Account.
     * Edit one Account.
     * @param accounts
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editAccount(accounts: Accounts, observe?: 'body', reportProgress?: boolean): Observable<Accounts>;
    editAccount(accounts: Accounts, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Accounts>>;
    editAccount(accounts: Accounts, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Accounts>>;
    /**
     * Get one Account.
     * Get one Account.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAccountById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Accounts>;
    getAccountById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Accounts>>;
    getAccountById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Accounts>>;
    /**
     * Get all Accounts.
     * Get all Accounts.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAccounts(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Accounts>>;
    getAccounts(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Accounts>>>;
    getAccounts(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Accounts>>>;
}
