import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Carriers } from '../models/carriers';
import { DeletedResponse } from '../models/deletedResponse';
import { Configuration } from '../configuration';
import { CarriersServiceInterface } from './carriers.serviceInterface';
export declare class CarriersService implements CarriersServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one carrier.
     * Add one carrier.
     * @param carriers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addCarrier(carriers: Carriers, observe?: 'body', reportProgress?: boolean): Observable<Carriers>;
    addCarrier(carriers: Carriers, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Carriers>>;
    addCarrier(carriers: Carriers, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Carriers>>;
    /**
     * Delete one carrier.
     * Delete one carrier.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteCarrier(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteCarrier(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteCarrier(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one carrier.
     * Edit one carrier.
     * @param carriers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editCarrier(carriers: Carriers, observe?: 'body', reportProgress?: boolean): Observable<Carriers>;
    editCarrier(carriers: Carriers, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Carriers>>;
    editCarrier(carriers: Carriers, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Carriers>>;
    /**
     * Get one carrier.
     * Get one carrier.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCarrierById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Carriers>;
    getCarrierById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Carriers>>;
    getCarrierById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Carriers>>;
    /**
     * Get all carriers.
     * Get all carriers.
     * @param skip number of item to skip (not included the first)
     * @param limit max records to return (included the last)
     * @param orderBy order by property. Put &#39;-&#39; at the beginning to descendant order.
     * @param filter filter data. NOT SUPPORTED YET.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCarriers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Carriers>>;
    getCarriers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Carriers>>>;
    getCarriers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Carriers>>>;
}
