import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { Deliveries } from '../models/deliveries';
import { Configuration } from '../configuration';
import { DeliveriesServiceInterface } from './deliveries.serviceInterface';
export declare class DeliveriesService implements DeliveriesServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one Delivery.
     * Add one Delivery.
     * @param deliveries
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addDelivery(deliveries: Deliveries, observe?: 'body', reportProgress?: boolean): Observable<Deliveries>;
    addDelivery(deliveries: Deliveries, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Deliveries>>;
    addDelivery(deliveries: Deliveries, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Deliveries>>;
    /**
     * Delete one Delivery.
     * Delete one Delivery.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteDelivery(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteDelivery(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteDelivery(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one Delivery.
     * Edit one Delivery.
     * @param deliveries
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editDelivery(deliveries: Deliveries, observe?: 'body', reportProgress?: boolean): Observable<Deliveries>;
    editDelivery(deliveries: Deliveries, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Deliveries>>;
    editDelivery(deliveries: Deliveries, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Deliveries>>;
    /**
     * Get all Deliveries.
     * Get all Deliveries.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Deliveries>>;
    getDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Deliveries>>>;
    getDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Deliveries>>>;
    /**
     * Get one Delivery.
     * Get one Delivery.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Deliveries>;
    getDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Deliveries>>;
    getDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Deliveries>>;
}
