import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { JourneyDeliveries } from '../models/journeyDeliveries';
import { Configuration } from '../configuration';
import { JourneyDeliveriesServiceInterface } from './journeyDeliveries.serviceInterface';
export declare class JourneyDeliveriesService implements JourneyDeliveriesServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one JourneyDelivery.
     * Add one JourneyDelivery.
     * @param handedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'body', reportProgress?: boolean): Observable<JourneyDeliveries>;
    addJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<JourneyDeliveries>>;
    addJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<JourneyDeliveries>>;
    /**
     * Delete one JourneyDelivery.
     * Delete one JourneyDelivery.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteJourneyDelivery(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteJourneyDelivery(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteJourneyDelivery(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one JourneyDelivery.
     * Edit one JourneyDelivery.
     * @param handedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'body', reportProgress?: boolean): Observable<JourneyDeliveries>;
    editJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<JourneyDeliveries>>;
    editJourneyDelivery(handedOvers: JourneyDeliveries, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<JourneyDeliveries>>;
    /**
     * Get all JourneyDeliveries.
     * Get all JourneyDeliveries.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getJourneyDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<JourneyDeliveries>>;
    getJourneyDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<JourneyDeliveries>>>;
    getJourneyDeliveries(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<JourneyDeliveries>>>;
    /**
     * Get one JourneyDelivery.
     * Get one JourneyDelivery.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getJourneyDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<JourneyDeliveries>;
    getJourneyDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<JourneyDeliveries>>;
    getJourneyDeliveryById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<JourneyDeliveries>>;
}
