import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { Journeys } from '../models/journeys';
import { Configuration } from '../configuration';
import { JourneysServiceInterface } from './journeys.serviceInterface';
export declare class JourneysService implements JourneysServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one Journey.
     * Add one Journey.
     * @param journeys
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addJourney(journeys: Journeys, observe?: 'body', reportProgress?: boolean): Observable<Journeys>;
    addJourney(journeys: Journeys, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Journeys>>;
    addJourney(journeys: Journeys, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Journeys>>;
    /**
     * Delete one Journey.
     * Delete one Journey.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteJourney(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteJourney(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteJourney(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one Journey.
     * Edit one Journey.
     * @param journeys
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editJourney(journeys: Journeys, observe?: 'body', reportProgress?: boolean): Observable<Journeys>;
    editJourney(journeys: Journeys, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Journeys>>;
    editJourney(journeys: Journeys, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Journeys>>;
    /**
     * Get one Journey.
     * Get one Journey.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getJourneyById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Journeys>;
    getJourneyById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Journeys>>;
    getJourneyById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Journeys>>;
    /**
     * Get all Journeys.
     * Get all Journeys.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getJourneys(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Journeys>>;
    getJourneys(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Journeys>>>;
    getJourneys(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Journeys>>>;
}
