import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { Locations } from '../models/locations';
import { Configuration } from '../configuration';
import { LocationsServiceInterface } from './locations.serviceInterface';
export declare class LocationsService implements LocationsServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one Location.
     * Add one Location.
     * @param locations
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addLocation(locations: Locations, observe?: 'body', reportProgress?: boolean): Observable<Locations>;
    addLocation(locations: Locations, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Locations>>;
    addLocation(locations: Locations, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Locations>>;
    /**
     * Delete one Location.
     * Delete one Location.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteLocation(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteLocation(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteLocation(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one Location.
     * Edit one Location.
     * @param locations
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editLocation(locations: Locations, observe?: 'body', reportProgress?: boolean): Observable<Locations>;
    editLocation(locations: Locations, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Locations>>;
    editLocation(locations: Locations, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Locations>>;
    /**
     * Get one Location.
     * Get one Location.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getLocationById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Locations>;
    getLocationById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Locations>>;
    getLocationById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Locations>>;
    /**
     * Get all Locations.
     * Get all Locations.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getLocations(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Locations>>;
    getLocations(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Locations>>>;
    getLocations(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Locations>>>;
}
