import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeletedResponse } from '../models/deletedResponse';
import { LoginObject } from '../models/loginObject';
import { Users } from '../models/users';
import { Configuration } from '../configuration';
import { UsersServiceInterface } from './users.serviceInterface';
export declare class UsersService implements UsersServiceInterface {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * Add one User.
     * Add one User.
     * @param handedOvers
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addUser(handedOvers: Users, observe?: 'body', reportProgress?: boolean): Observable<Users>;
    addUser(handedOvers: Users, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Users>>;
    addUser(handedOvers: Users, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Users>>;
    /**
     * Delete one Users.
     * Delete one User.
     * @param id id to delete
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteUsers(id: number, observe?: 'body', reportProgress?: boolean): Observable<DeletedResponse>;
    deleteUsers(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<DeletedResponse>>;
    deleteUsers(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<DeletedResponse>>;
    /**
     * Edit one User.
     * Edit one User.
     * @param user
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    editUser(user: Users, observe?: 'body', reportProgress?: boolean): Observable<Users>;
    editUser(user: Users, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Users>>;
    editUser(user: Users, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Users>>;
    /**
     * Get one User.
     * Get one User.
     * @param id id to delete
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getUserById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'body', reportProgress?: boolean): Observable<Users>;
    getUserById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Users>>;
    getUserById(id: number, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Users>>;
    /**
     * Get all Users.
     * Get all Users.
     * @param skip number of item to skip
     * @param limit max records to return
     * @param orderBy order by property.
     * @param filter filter data.
     * @param deleted Get all, daleted, not deleted data. Default not deleted.
     * @param userId id of user. Only for admin, editor or viewer users.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getUsers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Users>>;
    getUsers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Users>>>;
    getUsers(skip: number, limit: number, orderBy?: string, filter?: string, deleted?: 'NOT-DELETED' | 'DELETED' | 'ALL', userId?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Users>>>;
    /**
     * Logs user into the system
     *
     * @param email The user email for login
     * @param password The password for login in clear text
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    login(email: string, password: string, observe?: 'body', reportProgress?: boolean): Observable<LoginObject>;
    login(email: string, password: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<LoginObject>>;
    login(email: string, password: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<LoginObject>>;
    /**
     * Logs out current logged in user session
     *
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logout(observe?: 'body', reportProgress?: boolean): Observable<string>;
    logout(observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<string>>;
    logout(observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<string>>;
    /**
     * Get user info by token
     *
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    verifyToken(observe?: 'body', reportProgress?: boolean): Observable<LoginObject>;
    verifyToken(observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<LoginObject>>;
    verifyToken(observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<LoginObject>>;
}
